#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QTimer>
#include <QAction>
#include <QSystemTrayIcon>
#include <QMenu>
#include <QSettings>
#include <QKeySequence>

#include "kaction.h"

#include "optionsdialog.h"

namespace Ui {
    class MainWindow;
}

class MainWindow : public QMainWindow {
    Q_OBJECT
public:
    MainWindow(QWidget *parent = 0);
    ~MainWindow();
    void createActions();
    void createTrayIcon();

protected:
    void changeEvent(QEvent *e);

public slots:
    void updateTime();
    void slotDisableAOT();
    void slotHide();
    void slotShow();
    void slotPause();
    void slotResume();
    void slotReset();
    void slotOptions();
    void slotKeySequenceChanged(QKeySequence seq);
    void slotTogglePause();

private:
    Ui::MainWindow *ui;
    QSettings *settings;
    QTimer *timer;
    uint seconds;
    bool alwaysOnTop;

    QAction *pauseAction;
    QAction *resumeAction;
    QAction *resetAction;
    QAction *hideAction;
    QAction *showAction;
    QAction *disableAOTAction;
    QAction *openOptionsDialogAction;
    QAction *quitAction;

    KAction *togglePauseWithKeyboardAction;

    QSystemTrayIcon *trayIcon;
    QMenu *trayIconMenu;

    optionsDialog *m_optionsDialog;
};

#endif // MAINWINDOW_H
